==> walkers-fabric-1.18.2-4.5-sources.jar: tocraft/walkers/ability/impl/RabbitAbility.java <==
package tocraft.walkers.ability.impl;

import net.minecraft.class_1308;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2271;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_5712;
import tocraft.walkers.ability.ShapeAbility;

public class RabbitAbility<T extends class_1308> extends ShapeAbility<T> {
    @Override
    public void onUse(class_1657 player, T shape, class_1937 world) {
        if (!world.method_8608()) {
            class_2338 blockPos = player.method_24515().method_10084();
            class_2680 blockState = world.method_8320(blockPos);
            class_2248 block = blockState.method_26204();
            if (block instanceof class_2271) {
                int i = blockState.method_11654(class_2271.field_10835);
                if (i == 0) {
                    world.method_8652(blockPos, class_2246.field_10124.method_9564(), 2);
                    world.method_8651(blockPos, true, player);
                } else {
                    world.method_8652(blockPos, blockState.method_11657(class_2271.field_10835, i - 1), 2);
                    world.method_32888(player, class_5712.field_28733, blockPos);
                    world.method_8444(player, 2001, blockPos, class_2248.method_9507(blockState));
                    player.method_32876(class_5712.field_28735);
                    player.method_7344().method_7585(1, 0.1F);
                }
            }
            world.method_8465(player, player.method_23317(), player.method_23318(), player.method_23321(), class_3417.field_14693, class_3419.field_15248, 1.0F, 1.0F);
        }
    }

    @Override
    public int getDefaultCooldown() {
        return 40;
    }

    @Override
    public class_1792 getIcon() {
        return class_1802.field_8179;
    }
}

==> walkers-fabric-1.20.1-4.2-sources.jar: tocraft/walkers/ability/impl/RabbitAbility.java <==
package tocraft.walkers.ability.impl;

import net.minecraft.class_1308;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2271;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_5712;
import tocraft.walkers.ability.ShapeAbility;

public class RabbitAbility<T extends class_1308> extends ShapeAbility<T> {
    @Override
    public void onUse(class_1657 player, T shape, class_1937 world) {
        if (!world.method_8608()) {
            class_2338 blockPos = player.method_24515().method_10084();
            class_2680 blockState = world.method_8320(blockPos);
            class_2248 block = blockState.method_26204();
            if (block instanceof class_2271) {
                int i = blockState.method_11654(class_2271.field_10835);
                if (i == 0) {
                    world.method_8652(blockPos, class_2246.field_10124.method_9564(), 2);
                    world.method_8651(blockPos, true, player);
                } else {
                    world.method_8652(blockPos, blockState.method_11657(class_2271.field_10835, i - 1), 2);
                    world.method_43276(class_5712.field_28733, blockPos, class_5712.class_7397.method_43285(player));
                    world.method_8444(player, 2001, blockPos, class_2248.method_9507(blockState));
                    player.method_32876(class_5712.field_28735);
                    player.method_7344().method_7585(1, 0.1F);
                }
            }
            world.method_43128(player, player.method_23317(), player.method_23318(), player.method_23321(), class_3417.field_14693, class_3419.field_15248, 1.0F, 1.0F);
        }
    }

    @Override
    public int getDefaultCooldown() {
        return 40;
    }

    @Override
    public class_1792 getIcon() {
        return class_1802.field_8179;
    }
}
